@@ -232,7 +232,8 @@ static void init_color_data(void)
 #ifdef __3DS__
 		color_data[i] = angband_color_table[i][1] << 24 |
 		                angband_color_table[i][2] << 16 |
-		                angband_color_table[i][3] << 8;
+		                angband_color_table[i][3] << 8 |
+		                0xFF;
 #else
 		color_data[i] = RGB15(angband_color_table[i][1] >> 3,
 		                      angband_color_table[i][2] >> 3,
@@ -468,10 +469,6 @@ static errr Term_wipe_nds(int x, int y, int n)
  * default "spaces", and all other colors should be drawn in
  * the "normal" color in a monochrome environment.
  *
- * Note that if you have changed the "attr_blank" to something
- * which is not black, then this function must be able to draw
- * the resulting "blank" correctly.
- *
  * Note that this function must correctly handle "black" text if
  * the "always_text" flag is set, if this flag is not set, all the
  * "black" text will be handled by the "Term_wipe_xxx()" hook.
